RSpec.describe EnglishNumber do
  subject(:eng_num) { described_class }
  
  # Integration tests
  it 'includes Translate module' do
    expect(eng_num.included_modules).to include(Translate)
  end
  
  describe '::Translate module' do
    
    context 'when single digit' do
  
      it 'translates one digit numbers to English words' do
        expect(eng_num.new(6).in_english).to eq('six')
      end
      
      it 'translates negative one digit numbers' do
        expect(eng_num.new(-7).in_english).to eq('minus-seven')
      end
      
      it 'translates float numbers to English words rounded down' do
        expect(eng_num.new(5.5).in_english).to eq('five')
      end
      
    end
    
    context 'when two digits', if: Translate::DIGITS_LIMIT > 1 do
    
      it 'translates two digit numbers < 20 to English words' do
        expect(eng_num.new(11).in_english).to eq('eleven')
      end
      
      it 'translates two digit numbers >= 20 to English words' do
        expect(eng_num.new(22).in_english).to eq('twenty-two')
      end
      
      it 'translates negative two digit numbers < 20' do
        expect(eng_num.new(-15).in_english).to eq('minus-fifteen')
      end
    
      it 'translates negative two digit numbers >= 20' do
        expect(eng_num.new(-43).in_english).to eq('minus-forty-three')
      end
      
      it 'translates float numbers to English words rounded down' do
        expect(eng_num.new(24.5).in_english).to eq('twenty-four')
      end
      
      it 'translates multiplications of 10 properly' do
        expect(eng_num.new(30).in_english).to eq('thirty')
      end
      
    end
    
    context 'when three digits', if: Translate::DIGITS_LIMIT > 2 do
    
      it 'translates three digit numbers to English words' do
        expect(eng_num.new(765).in_english).to eq('seven-hundred-sixty-five')
      end
      
      it 'translates negative three digit numbers' do
        expect(eng_num.new(-145).in_english).to eq('minus-one-hundred-forty-five')
      end
    
      it 'translates multiplications of 100 properly' do
        expect(eng_num.new(400).in_english).to eq('four-hundred')
      end
    
    end
    
    context 'when over set limit of digits' do
      let(:limit) { 10**Translate::DIGITS_LIMIT }
      let(:num) { rand(limit..10*limit) }
      
      it 'doesn\'t translate positive numbers with more digits than limit' do
        expect(eng_num.new(num).in_english).to eq(nil)
      end
     
      it 'doesn\'t translate negative numbers with more digits than limit' do
        expect(eng_num.new(0-num).in_english).to eq(nil)
      end 
    end
    
  end
  
  it 'includes Compute module' do
    expect(eng_num.included_modules).to include(Compute)
  end
  
  describe '::Compute module' do
    
    context 'adds numbers and returns new object' do
      
      it 'single digits' do
        expect((eng_num.new(2) + eng_num.new(6)).num).to eq(8)
      end
      
      it 'two digits', if: Translate::DIGITS_LIMIT > 1 do
        expect((eng_num.new(12) + eng_num.new(86)).num).to eq(98)
      end
      
      it 'three digits', if: Translate::DIGITS_LIMIT > 2 do
        expect((eng_num.new(112) + eng_num.new(245)).num).to eq(357)
      end
    end
    
    context 'subtracts numbers and returns new object' do
      
      it 'single digits' do
        expect((eng_num.new(7) - eng_num.new(3)).num).to eq(4)
      end
      
      it 'two digits' do
        expect((eng_num.new(10) - eng_num.new(17)).num).to eq(-7)
      end
      
      it 'three digits' do
        expect((eng_num.new(765) - eng_num.new(265)).num).to eq(500)
      end
      
    end
    
    context 'multiplies numbers and returns new object' do
      
      it 'single digits' do
        expect((eng_num.new(2) * eng_num.new(3)).num).to eq(6)
      end
      
      it 'two digits' do
        expect((eng_num.new(11) * eng_num.new(45)).num).to eq(495)
      end
      
      it 'three digits' do
        expect((eng_num.new(765) - eng_num.new(265)).num).to eq(500)
      end
      
    end
    
    
    context 'divides numbers and returns new object' do
      
      it 'single digits' do
        expect((eng_num.new(8) / eng_num.new(2)).num).to eq(4)
      end
      
      it 'two digits' do
        expect((eng_num.new(66) / eng_num.new(3)).num).to eq(22)
      end
      
      it 'three digits' do
        expect((eng_num.new(754) / eng_num.new(4)).num).to eq(188)
      end
    end
    
  end
end
