RSpec.describe EnglishNumber do
  subject(:eng_num) { described_class }
  
  context 'has one instance variable' do
    
    it 'throws error for no arguments given' do
      expect { eng_num.new }.to raise_error(ArgumentError)
    end
    
    it 'runs with one number argument given' do
      expect { eng_num.new(6) }.not_to raise_error
    end
    
    it 'throws error for two arguments given' do
      expect { eng_num.new(2,4) }.to raise_error(ArgumentError)
    end
    
  end
  
  context 'accepts only numeric arguments' do
  
    it 'throws error for string argument' do
      expect { eng_num.new('') }.to raise_error(ArgumentError)
    end
  
    it 'throws error for array argument' do
      expect { eng_num.new(Array.new) }.to raise_error(ArgumentError)
    end
    
    it 'accepts float argument' do
      expect { eng_num.new(4.5) }.not_to raise_error
    end
    
    it 'accepts integer argument' do
      expect { eng_num.new(56) }.not_to raise_error
    end
    
    it 'handles integer argument greater than gem\'s limit' do
      expect { eng_num.new(523123) }.not_to raise_error
    end
    
  end
  
  context 'allows to read the number instance variable' do
    
    it 'doesn\'t throw error when the number is read' do
      expect { eng_num.new(43).num }.not_to raise_error
    end
    
    it 'reads the right number' do
      expect(eng_num.new(33).num).to eq(33)
    end
    
  end
  
end
