RSpec.describe FiveDigits do
  subject(:five_dig) { described_class }
  
  context 'modules' do
    
    it 'includes Compute module' do
      expect(five_dig.included_modules).to include(Compute)
    end
    
    it 'includes Translate module' do
      expect(five_dig.included_modules).to include(Translate)
    end
    
  end
  
  context '#run' do
    let(:limit) { 10**Translate::DIGITS_LIMIT }
    let(:num) { rand(limit/10..limit) }
    let(:inst) { instance_double('FiveDigits') }
  
    it 'responds to class method #run(num)' do
      expect(five_dig).to respond_to(:run).with(1).argument
      five_dig.run(num)
    end
    
    it 'when #run used it it invokes #in_words on new instance' do
      allow(five_dig).to receive(:new).with(num) { inst }
      expect(inst).to receive(:in_words)
      five_dig.run(num)
    end
  
  end
  
  context '#in_words', if: Translate::DIGITS_LIMIT > 4 do

    context 'works for five-digit numbers:' do
      it '10000' do
        expect(five_dig.new(10000).in_words).to eq('ten-thousand')
      end
      it '10010' do
        expect(five_dig.new(10010).in_words).to eq('ten-thousand-ten')
      end
      it '15210' do
        expect(five_dig.new(15210).in_words).to eq('fifteen-thousand-two-hundred-ten')
      end
      it '27378' do
        expect(five_dig.new(27378).in_words).to eq('twenty-seven-thousand-three-hundred-seventy-eight')
      end
      it '30000' do
        expect(five_dig.new(30000).in_words).to eq('thirty-thousand')
      end
      it '31500' do
        expect(five_dig.new(31500).in_words).to eq('thirty-one-thousand-five-hundred')
      end
      it '60000' do
        expect(five_dig.new(60000).in_words).to eq('sixty-thousand')
      end
      it '87324' do
        expect(five_dig.new(87324).in_words).to eq('eighty-seven-thousand-three-hundred-twenty-four')
      end
      it '99999' do
        expect(five_dig.new(99999).in_words).to eq('ninety-nine-thousand-nine-hundred-ninety-nine')
      end
    end
  
  end
  
end