RSpec.describe FourDigits do
  subject(:four_dig) { described_class }
  
  context 'modules' do
    
    it 'includes Compute module' do
      expect(four_dig.included_modules).to include(Compute)
    end
    
    it 'includes Translate module' do
      expect(four_dig.included_modules).to include(Translate)
    end
    
  end
  
  context '#run' do
    let(:limit) { 10**Translate::DIGITS_LIMIT }
    let(:num) { rand(limit/10..limit) }
    let(:inst) { instance_double('FourDigits') }
  
    it 'responds to class method #run(num)' do
      expect(four_dig).to respond_to(:run).with(1).argument
      four_dig.run(num)
    end
    
    it 'when #run used it it invokes #in_words on new instance' do
      allow(four_dig).to receive(:new).with(num) { inst }
      expect(inst).to receive(:in_words)
      four_dig.run(num)
    end
  
  end
  
  context '#in_words', if: Translate::DIGITS_LIMIT > 3 do

    context 'works for four-digit numbers:' do
      it '1000' do
        expect(four_dig.new(1000).in_words).to eq('one-thousand')
      end
      it '1010' do
        expect(four_dig.new(1010).in_words).to eq('one-thousand-ten')
      end
      it '1210' do
        expect(four_dig.new(1210).in_words).to eq('one-thousand-two-hundred-ten')
      end
      it '2378' do
        expect(four_dig.new(2378).in_words).to eq('two-thousand-three-hundred-seventy-eight')
      end
      it '3000' do
        expect(four_dig.new(3000).in_words).to eq('three-thousand')
      end
      it '3500' do
        expect(four_dig.new(3500).in_words).to eq('three-thousand-five-hundred')
      end
      it '6000' do
        expect(four_dig.new(6001).in_words).to eq('six-thousand-one')
      end
      it '8732' do
        expect(four_dig.new(8732).in_words).to eq('eight-thousand-seven-hundred-thirty-two')
      end
      it '9999' do
        expect(four_dig.new(9999).in_words).to eq('nine-thousand-nine-hundred-ninety-nine')
      end
    end
  
  end
  
end