RSpec.describe ThreeDigits do
  subject(:three_dig) { described_class }
  
  context 'modules' do
    
    it 'includes Compute module' do
      expect(three_dig.included_modules).to include(Compute)
    end
    
    it 'includes Translate module' do
      expect(three_dig.included_modules).to include(Translate)
    end
    
  end
  
  context '#run' do
    let(:limit) { 10**Translate::DIGITS_LIMIT }
    let(:num) { rand(limit/10..limit) }
    let(:inst) { instance_double('ThreeDigits') }
  
    it 'responds to class method #run(num)' do
      expect(three_dig).to respond_to(:run).with(1).argument
      three_dig.run(num)
    end
    
    it 'when #run used it it invokes #in_words on new instance' do
      allow(three_dig).to receive(:new).with(num) { inst }
      expect(inst).to receive(:in_words)
      three_dig.run(num)
    end
  
  end
  
  context '#in_words', if: Translate::DIGITS_LIMIT > 2 do

    context 'works for three-digit numbers:' do
      it '100' do
        expect(three_dig.new(100).in_words).to eq('one-hundred')
      end
      it '121' do
        expect(three_dig.new(121).in_words).to eq('one-hundred-twenty-one')
      end
      it '237' do
        expect(three_dig.new(237).in_words).to eq('two-hundred-thirty-seven')
      end
      it '300' do
        expect(three_dig.new(300).in_words).to eq('three-hundred')
      end
      it '600' do
        expect(three_dig.new(600).in_words).to eq('six-hundred')
      end
      it '873' do
        expect(three_dig.new(873).in_words).to eq('eight-hundred-seventy-three')
      end
      it '999' do
        expect(three_dig.new(999).in_words).to eq('nine-hundred-ninety-nine')
      end
    end
  
  end
  
end