RSpec.describe TwoDigits do
  subject(:two_dig) { described_class }
  
  context 'modules' do
    
    it 'includes Compute module' do
      expect(two_dig.included_modules).to include(Compute)
    end
    
    it 'includes Translate module' do
      expect(two_dig.included_modules).to include(Translate)
    end
    
  end
  
  context '#run' do
    let(:limit) { 10**Translate::DIGITS_LIMIT }
    let(:num) { rand(limit/10..limit) }
    let(:inst) { instance_double('TwoDigits') }
  
    it 'responds to class method #run(num)' do
      expect(two_dig).to respond_to(:run).with(1).argument
      two_dig.run(num)
    end
    
    it 'when #run used it it invokes #in_words on new instance' do
      allow(two_dig).to receive(:new).with(num) { inst }
      expect(inst).to receive(:in_words)
      two_dig.run(num)
    end
  
  end
  
  context '#in_words', if: Translate::DIGITS_LIMIT > 1 do

    context 'works for two-digit numbers smaller than 20:' do
      it '10' do
        expect(two_dig.new(10).in_words).to eq('ten')
      end
      it '16' do
        expect(two_dig.new(16).in_words).to eq('sixteen')
      end
      it '19' do
        expect(two_dig.new(19).in_words).to eq('nineteen')
      end
    end
    
    context 'works for two-digit numbers greater than 19' do
      it '25' do
        expect(two_dig.new(25).in_words).to eq('twenty-five')
      end
      it '50' do
        expect(two_dig.new(50).in_words).to eq('fifty')
      end
      it '99' do
        expect(two_dig.new(99).in_words).to eq('ninety-nine')
      end
      
    end
  end
  
end